# Stellar

## Overview

Stellar is a program that runs pilots to increase quality of care for UHG members. For more information and to see how this package is used, see the [project_stellar repo](https://github.com/optum-labs/project_stellar).

## Installation

In the terminal, run: <br>
`pip install stellarcare`

## Motivation

Right now, methods are mainly geared towards building cohorts for propensity score matching in causal inference analyses of different Stellar pilots. The vision is to continue to expand this repo to make it easier to revise and re-run Stellar analyses for stakeholders. The hope is that by containing methods in a standalone repo, fewer mistakes will be made and code review will be easier to perform.

## Bugs
To report a bug, [please create an issue](https://github.com/optum-labs/stellar/issues).
